@@ -16,11 +16,11 @@ class Statuses(Enum):
 
 class Downloader:
     class Request:
-        def __init__(self, url, proxy=[], enable_proxy=True) -> None:
+        def __init__(self, url, proxy=[], enable_proxy=True, headers = {}) -> None:
             self.url = url
             self.proxies = proxy
             self.enable_proxy = enable_proxy
-
+            self.headers = headers
         def get_proxy(self):
             if not self.proxies:
                 return None
@@ -45,7 +45,7 @@ class Downloader:
             file_name = location + '/' + folder_name + '/' + folder_name + '_episode_' + str(episode) + '.mp4'
             path = pathlib.Path(location + '/' + folder_name)
             path.mkdir(parents=True, exist_ok=True)
-            headers = {}
+            headers = request.headers
             if 'user-agent' not in headers:
                 headers['user-agent'] = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) Gecko/20100101Firefox/56.0"
 
