@@ -20,7 +20,6 @@ class HtmlExtractor:
         self.html_url = html_url
 
     def extract_iframe_src(self):
-
         try:
             page = requests.get(self.html_url, timeout=30)
             soup = BeautifulSoup(page.content, "html.parser")
@@ -31,10 +30,10 @@ class HtmlExtractor:
             logging.error("Error finding iframe at url {0} with error {1}".format(self.html_url, e))
             raise Exception("Error finding iframe at url {0} with error {1}".format(self.html_url, e)) from e
 
-
 class DynamicHtmlExtractor:
     class Request:
-        def __init__(self, url, timeout=30, wait=2, sleep=3, proxies=[], enable_proxy=True, auth=None) -> None:
+        def __init__(self, url, timeout=30, wait=2, sleep=3, proxies=[], enable_proxy=True, auth=None, headers = {}) -> None:
+            self.headers = headers
             self.url = url
             self.timeout = timeout
             self.wait = wait
@@ -73,23 +72,30 @@ class DynamicHtmlExtractor:
         except Exception as e:
             logging.error("Error finding divs at url {0} with error {1}".format(self.html_url, e))
             raise Exception("Error finding divs at url {0} with error {1}".format(self.html_url, e)) from e
+        finally:
+            if async_session:
+                async_session.close()
         result.reverse()
         return result
 
     def extract_download_div_class(self, request: Request) -> list:
         result = []
         proxy = request.get_proxy()
-        header = {
-            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36",
-            'referer': 'goload.pro'
-        }
-        try:
-            if not proxy or not request.enable_proxy:
-                page = HTMLSession().get(self.html_url, headers=header, timeout=request.timeout)
-            else:
-                page = HTMLSession().get(self.html_url, headers=header, timeout=request.timeout, proxies=proxy)
+        header = request.headers
+        if 'user-agent' not in header:
+            header['user-agent'] = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) Gecko/20100101Firefox/56.0"
 
-            page.html.render(wait=request.wait, sleep=request.sleep)
+        header['referer'] = 'goload.pro'
+
+
+        try:
+            session = HTMLSession()
+            if not proxy or not request.enable_proxy:
+                page = session.get(self.html_url, headers=header, timeout=request.timeout)
+            else:
+                page = session.get(self.html_url, headers=header, timeout=request.timeout, proxies=proxy)
+
+            page.html.render(wait=request.wait, sleep=request.sleep, timeout=request.timeout)
             element = page.html.find('#content-download')[0]
             if element:
                 captcha = element.html.find('iframe')
@@ -109,12 +115,15 @@ class DynamicHtmlExtractor:
             logging.error("Error finding divs at url {0} with error {1}".format(self.html_url, e))
             raise Exception(
                 "Error finding divs at url {0} with proxy {1} with error {2}".format(self.html_url, proxy, e)) from e
+        finally:
+            if session:
+                logging.info("Closing session")
+                session.close()
         result.reverse()
         return result
 
-# resultloop = asyncio.new_event_loop()
-# asyncio.set_event_loop(loop)
+
 # d = DynamicHtmlExtractor('https://goload.pro/download?id=MTQxNDI1&title=Otome+Game+no+Hametsu+Flag+shika+Nai+Akuyaku+Reijou+ni+Tensei+shiteshimatta...&typesub=SUB&sub=&cover=Y292ZXIvb3RvbWUtZ2FtZS1uby1oYW1ldHN1LWZsYWctc2hpa2EtbmFpLWFrdXlha3UtcmVpam91LW5pLXRlbnNlaS1zaGl0ZXNoaW1hdHRhLnBuZw==&mip=0.0.0.0&refer=https://gogoplay5.com/&ch=d41d8cd98f00b204e9800998ecf8427e&op=1')
-#
-# res = loop.run_until_complete(d.extract_download_div_class_parallel())
+# request = DynamicHtmlExtractor.Request(enable_proxy=False,url = 'https://goload.pro/download?id=MTQxNDI1&title=Otome+Game+no+Hametsu+Flag+shika+Nai+Akuyaku+Reijou+ni+Tensei+shiteshimatta...&typesub=SUB&sub=&cover=Y292ZXIvb3RvbWUtZ2FtZS1uby1oYW1ldHN1LWZsYWctc2hpa2EtbmFpLWFrdXlha3UtcmVpam91LW5pLXRlbnNlaS1zaGl0ZXNoaW1hdHRhLnBuZw==&mip=0.0.0.0&refer=https://gogoplay5.com/&ch=d41d8cd98f00b204e9800998ecf8427e&op=1')
+# res = d.extract_download_div_class(request)
 # print(res)
